@@ -10,7 +10,7 @@ import (
 	"strings"
 )
 
-func InstallZIP(data []byte) (err error) {
+func InstallZIP(data []byte, user bool) (err error) {
 	bytesReader := bytes.NewReader(data)
 
 	zipReader, err := zip.NewReader(bytesReader, int64(bytesReader.Len()))
@@ -50,7 +50,7 @@ func InstallZIP(data []byte) (err error) {
 	}
 
 	for _, font := range fonts {
-		if err = install(font); err != nil {
+		if err = install(font, user); err != nil {
 			return err
 		}
 	}
