@@ -14,7 +14,7 @@ import (
 // FontsDir denotes the path to the user's fonts directory on Unix-like systems.
 var FontsDir = path.Join(os.Getenv("HOME"), "/.local/share/fonts")
 
-func install(font *Font) (err error) {
+func install(font *Font, _ bool) (err error) {
 	// On Linux, fontconfig can understand subdirectories. So, to keep the
 	// font directory clean, install all font files for a particular font
 	// family into a subdirectory named after the family (with hyphens instead
